/*
 Feltételek - while ciklus
 Ameddig nyomjuk a gombot, fut a kalibrációs rutin. Ezalatt megkapjuk a szenzorból kiolvasott minimum és maximum értékeket.
 
 Áramkör:
 * fotóellenállás – 10 kiloohm ellenállással, nyomógomb – 10 kiloohm ellenállással, LED – 220 Ohm ellenállással
 
 created 17 Jan 2009
 modified 30 Aug 2011 by Tom Igoe
 */

// Állandókkal meghatározzuk a pineket:
const int sensorPin = A0;       // fotóellenállás
const int ledPin = 9;           // LED
const int indicatorLedPin = 13; // beépített LED
const int buttonPin = 2;        // nyomógomb

// Deklaráljuk a változókat:
int sensorMin = 1023;  // minimum szenzor érték
int sensorMax = 0;     // maximum szenzor érték
int sensorValue = 0;     // kiolvasott szenzor érték


void setup() {
  // meghatározzuk a LED pineket kimenetnek,
  // a gombot bemenetnek
  pinMode(indicatorLedPin, OUTPUT);
  pinMode (ledPin, OUTPUT);
  pinMode (buttonPin, INPUT);
}

void loop() {
  // Ha a gombot megnyomjuk, lefut a kalibrálás:
  while (digitalRead(buttonPin) == HIGH) {
    calibrate(); 
  }
  // A kalibrálás végén a „jelző” beépített LED kikapcsol:
  digitalWrite(indicatorLedPin, LOW);  

  // kiolvassuk a szenzort:
  sensorValue = analogRead(sensorPin);

  // az aktuális beolvasott szenzorértéket 
  // meghatározzuk: skálázzuk PWM-hez: 
  sensorValue = map(sensorValue, sensorMin, sensorMax, 0, 255);

  // abban az esetben, ha a beolvasott érték a kalibrációs 
  // értékeken kívülre esne, constrainnel 
  // bekényszerítjük 0-255 közé:
  sensorValue = constrain(sensorValue, 0, 255);

  // az értéket a PWM LED pinre küldjük:
  analogWrite(ledPin, sensorValue);
}

void calibrate() {
  // bekapcsoljuk a beépített LED-et, amikor a
  // kalibrálás megkezdődik:
  digitalWrite(indicatorLedPin, HIGH);
  // kiolvassuk a szenzort:
  sensorValue = analogRead(sensorPin);

  // rögzítsük a maximum szenzor értéket
  if (sensorValue > sensorMax) {
    sensorMax = sensorValue;
  }

  // rögzítsük a minimum szenzor értéket
  if (sensorValue < sensorMin) {
    sensorMin = sensorValue;
  }
}


